<?php
/**
 * Plugin Name: Quikblock
 * Plugin URI:  http://foxthemes.me/
 * Description: A beautiful collection of handy Gutenberg blocks to help you get started with the new WordPress editor.
 * Author: Foxthemes
 * Author URI:http://foxthemes.me/
 * Version: 1.0.0
 * License: GPL2+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 *
 * @package Quikblock
 */

/**
 * Exit if accessed directly
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Initialize the blocks
 */
function quikblock_loader() {

	$quikblock_includes_dir = plugin_dir_path( __FILE__ ) . 'includes/';
	$quikblock_src_dir      = plugin_dir_path( __FILE__ ) . 'src/';
	$quikblock_dist_dir     = plugin_dir_path( __FILE__ ) . 'dist/';

	/**
	 * Load the blocks functionality
	 */
	require_once plugin_dir_path( __FILE__ ) . 'dist/init.php';

	/**
	 * Load Getting Started page
	 */
	require_once plugin_dir_path( __FILE__ ) . 'dist/getting-started/getting-started.php';

	/**
	 * Load Social Block PHP
	 */
	require_once plugin_dir_path( __FILE__ ) . 'src/quikblocks/quikblock-sharing/index.php';

	/**
	 * Load Post Grid PHP
	 */
	require_once plugin_dir_path( __FILE__ ) . 'src/quikblocks/quikblock-post-grid/index.php';

	/**
	 * Load the newsletter block and related dependencies.
	 */
	if ( PHP_VERSION_ID >= 50600 ) {
		if ( ! class_exists( '\DrewM\MailChimp\MailChimp' ) ) {
			require_once $quikblock_includes_dir . 'libraries/drewm/mailchimp-api/MailChimp.php';
		}

		require_once $quikblock_includes_dir . 'exceptions/class-api-error-exception.php';
		require_once $quikblock_includes_dir . 'exceptions/class-mailchimp-api-error-exception.php';
		require_once $quikblock_includes_dir . 'interfaces/newsletter-provider-interface.php';
		require_once $quikblock_includes_dir . 'classes/class-mailchimp.php';
		require_once $quikblock_includes_dir . 'newsletter/newsletter-functions.php';
		require_once $quikblock_src_dir . 'quikblocks/quikblock-newsletter/index.php';
	}

	/**
	 * Compatibility functionality.
	 */
	require_once $quikblock_includes_dir . 'compat.php';
}
add_action( 'plugins_loaded', 'quikblock_loader' );


/**
 * Load the plugin textdomain
 */
function quikblock_init() {
	load_plugin_textdomain( 'quikblock', false, basename( dirname( __FILE__ ) ) . '/languages' );
}
add_action( 'init', 'quikblock_init' );


/**
 * Adds a redirect option during plugin activation on non-multisite installs.
 *
 * @param bool $network_wide Whether or not the plugin is being network activated.
 */
function quikblock_activate( $network_wide = false ) {
	// phpcs:ignore WordPress.Security.NonceVerification.Recommended -- Only used to do a redirect. False positive.
	if ( ! $network_wide && ! isset( $_GET['activate-multi'] ) ) {
		add_option( 'quikblock_do_activation_redirect', true );
	}
}
register_activation_hook( __FILE__, 'quikblock_activate' );


/**
 * Redirect to the Quikblock Getting Started page on single plugin activation.
 */
function quikblock_redirect() {
	if ( get_option( 'quikblock_do_activation_redirect', false ) ) {
		delete_option( 'quikblock_do_activation_redirect' );
		wp_safe_redirect( esc_url( admin_url( 'admin.php?page=quikblock' ) ) );
		exit;
	}
}
add_action( 'admin_init', 'quikblock_redirect' );


/**
 * Add image sizes
 */
function quikblock_image_sizes() {
	// Post Grid Block.
	add_image_size( 'qb-block-post-grid-landscape', 600, 400, true );
	add_image_size( 'qb-block-post-grid-square', 600, 600, true );
}
add_action( 'after_setup_theme', 'quikblock_image_sizes' );

/**
 * Returns the full path and filename of the main Quikblock plugin file.
 *
 * @return string
 */
function quikblock_main_plugin_file() {
	return __FILE__;
}
