const { __ } = wp.i18n;
const { Fragment } = wp.element;
const {
	SelectControl,
	ToggleControl,
} = wp.components;
const {
	PanelColorSettings,
} = wp.editor;


export default function ButtonSettings( props ) {
	const {
		enableButtonBackgroundColor,
		buttonBackgroundColor,
		onChangeButtonColor = () => {},
		enableButtonTextColor,
		buttonTextColor,
		onChangeButtonTextColor = () => {},
		enableButtonSize,
		buttonSize,
		onChangeButtonSize = () => {},
		enableButtonShape,
		buttonShape,
		onChangeButtonShape = () => {},
		enableButtonTarget,
		buttonTarget,
		onChangeButtonTarget = () => {},
	} = props;

	// Button size values
	const buttonSizeOptions = [
		{ value: 'qb-button-size-small', label: __( 'Small', 'quikblock' ) },
		{ value: 'qb-button-size-medium', label: __( 'Medium', 'quikblock' ) },
		{ value: 'qb-button-size-large', label: __( 'Large', 'quikblock' ) },
		{ value: 'qb-button-size-extralarge', label: __( 'Extra Large', 'quikblock' ) },
	];

	// Button shape
	const buttonShapeOptions = [
		{ value: 'qb-button-shape-square', label: __( 'Square', 'quikblock' ) },
		{ value: 'qb-button-shape-rounded', label: __( 'Rounded Square', 'quikblock' ) },
		{ value: 'qb-button-shape-circular', label: __( 'Circular', 'quikblock' ) },
	];

	return (
		<Fragment>
			{ enableButtonTarget != false && (
				<ToggleControl
					label={ __( 'Open link in new window', 'quikblock' ) }
					checked={ buttonTarget }
					onChange={ onChangeButtonTarget }
				/>
			) }
			{ enableButtonSize != false && (
				<SelectControl
					selected={ buttonSize }
					label={ __( 'Button Size', 'quikblock' ) }
					value={ buttonSize }
					options={ buttonSizeOptions.map( ({ value, label }) => ( {
						value: value,
						label: label,
					} ) ) }
					onChange={ onChangeButtonSize }
				/>
			) }
			{ enableButtonShape != false && (
				<SelectControl
					label={ __( 'Button Shape', 'quikblock' ) }
					value={ buttonShape }
					options={ buttonShapeOptions.map( ({ value, label }) => ( {
						value: value,
						label: label,
					} ) ) }
					onChange={ onChangeButtonShape }
				/>
			) }
			{ enableButtonBackgroundColor != false && (
				<PanelColorSettings
					title={ __( 'Button Background Color', 'quikblock' ) }
					initialOpen={ false }
					colorSettings={ [ {
						value: buttonBackgroundColor,
						onChange: onChangeButtonColor,
						label: __( 'Button Background Color', 'quikblock' ),
					} ] }
				>
				</PanelColorSettings>
			) }
			{ enableButtonTextColor != false && (
				<PanelColorSettings
					title={ __( 'Button Text Color', 'quikblock' ) }
					initialOpen={ false }
					colorSettings={ [ {
						value: buttonTextColor,
						onChange: onChangeButtonTextColor,
						label: __( 'Button Text Color', 'quikblock' ),
					} ] }
				>
				</PanelColorSettings>
			) }
		</Fragment>
	);
}
